.. PyGeneBe documentation master file, created by
   sphinx-quickstart on Wed Jan 10 11:59:22 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyGeneBe's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   installation
   limits
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
